@@ -677,6 +677,10 @@ BOOL CDraftFrame::SaveToDraft(BOOL confirm)
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 	CSummaryView *sv = mf->m_pListV;
 	CString path = app->m_app_path+"\\"+m_account+"\\draft";
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CString box_name;
+// end
 
 	CString body;
 	m_pEditV->GetText(body);
@@ -697,7 +701,23 @@ BOOL CDraftFrame::SaveToDraft(BOOL confirm)
 	// need or not confirmation dialog.
 	if(confirm){
 		CString message;
-		message.Format("%s\r\n\r\ndraft֕ۑ܂H", m_me.GetSubject());
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//		message.Format("%s\r\n\r\ndraft֕ۑ܂H", m_me.GetSubject());
+		GetPrivateProfileString(
+			"mailbox",
+			"draft",
+			"",
+			box_name.GetBuffer(BUF_LENGTH),
+			BUF_LENGTH,
+			app->m_app_path+"\\"+this->m_account+"\\account.ini");
+		box_name.ReleaseBuffer();
+		if(box_name.IsEmpty()){
+			message.Format("%s\r\n\r\n%s֕ۑ܂H", m_me.GetSubject(), DEF_BOXNAME_DRAFT);
+		}else{
+			message.Format("%s\r\n\r\n%s֕ۑ܂H", m_me.GetSubject(), box_name);
+		}
+// end
 		int check = this->MessageBox(message, "[̕ۑ", MB_YESNOCANCEL);
 		if(check == IDYES){
 			sv->SaveMail(path, m_me.GetMail(ME_GET_DRAFT), SMRY_STATUS_NONE, SMRY_COLUMN_TO);
