@@ -108,7 +108,11 @@ BOOL CFilter::SetData()
 		buf.TrimRight();
 		m_data.SetSize(m_data.GetSize()+1);
 		if(buf.Find("\\") == 0 && 
-			buf.Mid(1).FindOneOf("/:*?\\\"<>|") == -1){
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//			buf.Mid(1).FindOneOf("/:*?\\\"<>|") == -1){
+			buf.Mid(1).FindOneOf("/:*?\"<>|") == -1){
+// end
 			m_data[cnt].path = buf;
 		}else{
 			message.Format("%s ͕spathł", buf);
