@@ -37,6 +37,8 @@ public:
 
 // Iy[V
 public:
+	bool GetShowUnreadCount();
+	void SetShowUnreadCount(bool bShowUnreadCount);
 	BOOL AddFolder(HTREEITEM parent_ti);
 	BOOL DeleteFolder(HTREEITEM ti);
 	int GetSelectedItemKind();
@@ -100,6 +102,8 @@ protected:
 	afx_msg void OnPopupClearTrash();
 	//}}AFX_MSG
 	DECLARE_MESSAGE_MAP()
+private:
+	bool m_bShowUnreadCount;
 };
 
 /////////////////////////////////////////////////////////////////////////////
