@@ -31,10 +31,10 @@ CHeaderInfo::CHeaderInfo(CString buf)
 {
 	int point;
 
-	// oϐ̏
+	// initialyze
 	InitMemVal();
 
-	// [Ŝnꂽꍇ́Awb_؂o
+	// if whole mail is handed over, only header part is picked up.
 	switch(point = buf.Find("\r\n\r\n")){
 		case -1:
 			g_cstr2cstra(buf, m_undecoded_header, "\r\n");
@@ -60,13 +60,13 @@ CHeaderInfo::~CHeaderInfo()
 
 BOOL CHeaderInfo::DoIt(CStringArray &buf)
 {
-	// oϐ̏
+	// initialyze
 	InitMemVal();
 
 	int n = 0;
 	CString message;
 
-	// [Ŝnꂽꍇ́Awb_؂o
+	// if whole mail is handed over, only header part is picked up.
 	while(n < buf.GetSize()){
 		if(buf.GetAt(n) == "\x0D\x0A")
 			break;
@@ -157,7 +157,7 @@ void CHeaderInfo::Analyze()
 				m_enc = BIN;
 			if(g_cstr_compare(cte.GetBuffer(0), "base64"))
 				m_enc = BASE64;
-			if(g_cstr_compare(cte.GetBuffer(0), "x-gzip64")) // x-gzip64͎肠base64ɂƂizlib.dllKvȁj
+			if(g_cstr_compare(cte.GetBuffer(0), "x-gzip64")) // x-gzip64 is temporarily treat as base64 (zlib.dll is necessary)
 				m_enc = BASE64;
 			if(g_cstr_compare(cte.GetBuffer(0), "quoted-printable"))
 				m_enc = QUOTED_PRINTABLE;
@@ -191,15 +191,15 @@ void CHeaderInfo::Analyze()
 		}
 		regfree(&reg);
 	}
-	/* Content-Type݂Ȃꍇ́A
+	/* there is no Content-Type, below is applied
 	Content-Type: Text/Plain; charset=US-ASCII
-	Content-Transfer-Encoding: 7bit
-	ɂ */
+	Content-Transfer-Encoding: 7bit 
+	*/
 	if(m_type.IsEmpty())
 		m_type = "Text/Plain";
 	if(m_charset.IsEmpty())
 		m_charset = "US-ASCII ";
-	// InitMemVal()m_cte0i7bitjɐݒς
+	// m_cte is already set as 0(7bit) in InitMemVal()
 }
 
 CString CHeaderInfo::GetAllDecoded()
@@ -229,7 +229,7 @@ CString CHeaderInfo::GetOneLine(LPCTSTR key)
 	CString buf;
 	int n = 0;
 
-	// K\֐gׂ̑O
+	// prepare for regex
 	regex_t reg;
 	regmatch_t pmatch[1];
 
@@ -255,7 +255,7 @@ CString CHeaderInfo::GetOneLine(LPCTSTR key)
 	regfree(&reg);
 	delete r;
 	buf.Empty();
-	return buf; // Ȃꍇ͋Ԃ
+	return buf; // if nothing is matched, return empty
 }
 
 // [wb_folding whilte space폜֐
@@ -311,30 +311,34 @@ void CHeaderInfo::RemoveFoldingWhiteSpace(CStringArray *header)
 // [wb_base64Aquoted-printablefR[hAfolding white space菜AR[h̕ϊs
 void CHeaderInfo::Decode()
 {
-	
-	// K\֐p
-	regex_t reg; // K\i[p
-	regmatch_t pmatch[5]; // regexečʂi[
-	char *regex = "=\\?([^\\?]+)\\?([BQbq])\\?([^\\?]*)\\?="; // =?ISO-2022-JP?B?hogehogehoge?=ׂ̈̐K\
+	regex_t reg; // for regex
+	regmatch_t pmatch[5]; // result of regexec is put into this
+	char *regex = "=\\?([^\\?]+)\\?([BQbq])\\?([^\\?]*)\\?="; // for "=?ISO-2022-JP?B?hogehogehoge?="
 	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE);
 
 	CString temp1;
 	CString temp2;
 	CString buf;
-	CString encode_type;	// Bibase64jQiquoted-printablejƂ
-	CString char_type;		// ISO-2022-JPƂ
-	CString char_encoded;	// encodeꂽ
+	CString encode_type;	// B(base64) / Q(quoted-printable)
+	CString char_type;		// ISO-2022-JP and so on
+	CString char_encoded;	// part of encode
 	int len;
 	int n = 0;
 	CStringArray header;
 
-	// obt@pCStringArray̏ƃf[^̃Rs[
+	// initialyze and copy
 	header.RemoveAll();
 	header.Copy(m_undecoded_header);
 
-	// folding white space 菜
+	// folding white space 
 	RemoveFoldingWhiteSpace(&header);
 
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	// linear white space
+	RemoveLinearWhiteSpace(&header);
+// end
+
 	while(n < header.GetSize()){
 		buf = header.GetAt(n);
 		temp1.Empty();
@@ -342,7 +346,7 @@ void CHeaderInfo::Decode()
 
 		// K\base64Aquoted-printableencodeꂽ|ĂāAdecode
 		while(1){
-			if(buf.Find("?")==-1)// łregexec()܂breakB
+			if(buf.Find("?")==-1)
 				break;
 
 			if(0 != regexec(&reg, buf, 4, pmatch, 0))
@@ -373,7 +377,7 @@ void CHeaderInfo::Decode()
 			temp1		+=	buf.Mid(pmatch[0].rm_eo);
 			buf			=	temp1;
 		}
-		// R[h̕ϊ
+		// convert char code
 		CCodeConvert cc(buf);
 		buf = cc.ToSjis();
 		m_decoded_header.Add(buf);
@@ -501,8 +505,8 @@ CString CHeaderInfo::ReformDate(CString buf)
 	CString second;
 	CString zone;
 
-	regex_t reg; // K\i[p
-	regmatch_t pmatch[10]; // regexečʂi[
+	regex_t reg; // for regex
+	regmatch_t pmatch[10]; // result of regexec is put into this
 
 	char *regex = "Date:[ \t]*([a-zA-Z]+)*,* *([0-9]+) +([a-zA-Z]+) +([0-9]+) +([0-9]+):([0-9]+):*([0-9]*) +([+-0-9a-zA-Z]*)";
 //		Date:     Mon, 3 Feb 2003 00:00:43 -0600
@@ -576,8 +580,8 @@ CString CHeaderInfo::ReformDate(CString buf)
 
 void CHeaderInfo::AnalyzeCT()
 {
-	regex_t reg; // K\i[p
-	regmatch_t pmatch[2]; // regexečʂi[
+	regex_t reg; // for regex
+	regmatch_t pmatch[2]; // result of regexec is put into this
 
 	// type/subtype
 	char *regex = "^content-type: *([^;\r\n]+).*$";
@@ -611,7 +615,7 @@ void CHeaderInfo::AnalyzeCT()
 	}
 	regfree(&reg);
 
-	// protocol pgp/mimȅꍇ
+	// protocol pgp/mime
 	regex = "protocol= *\"*([^\";\r\n]+)\"*";
 	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE | REG_ICASE);
 	if(0 == regexec(&reg, m_ct, 2, pmatch, 0)){
@@ -622,8 +626,8 @@ void CHeaderInfo::AnalyzeCT()
 
 void CHeaderInfo::AnalyzeCD()
 {
-	regex_t reg; // K\i[p
-	regmatch_t pmatch[2]; // regexečʂi[
+	regex_t reg; // for regex
+	regmatch_t pmatch[2]; // result of regexec is put into this
 
 	// filename
 	char *regex	= "filename= *\"*([^;\"\r\n]+)\"*";
@@ -671,3 +675,33 @@ void CHeaderInfo::InitMemVal()
 	m_undecoded_header.RemoveAll();
 	m_enc = SEVEN_BIT; // 7bit
 }
+
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+void CHeaderInfo::RemoveLinearWhiteSpace(CStringArray *header)
+{
+	CString buf1;
+	CString buf2;
+	regex_t reg; // for regex
+	regmatch_t pmatch[3]; // result of regexec is put into this
+	char *regex = "=\\?[^\\?]+\\?[BQbq]\\?[^\\?]*\\?=([ \t]+)=\\?[^\\?]+\\?[BQbq]\\?[^\\?]*\\?="; // regex for "=?ISO-2022-JP?B?hogehogehoge?= =?ISO-2022-JP?B?hogehogehoge?="
+	regcomp(&reg, regex, REG_EXTENDED | REG_NEWLINE);
+
+	for(int i=0; i<header->GetSize(); i++){
+		buf1 = header->GetAt(i);
+		if(buf1.Find("?")==-1){
+				continue;
+		}
+		while(0 == regexec(&reg, buf1, 2, pmatch, 0)){
+			buf2 +=	buf1.Left(pmatch[1].rm_so);
+			buf1 = buf1.Mid(pmatch[1].rm_eo);
+		}
+		if(!buf1.IsEmpty()){
+			buf2 += buf1;
+		}
+		header->SetAt(i, buf2);
+		buf2.Empty();
+	}
+	regfree(&reg);
+}
+// end
\ No newline at end of file
