@@ -75,9 +75,7 @@ void CHeaderView::OnInitialUpdate()
 	this->GetRichEditCtrl().SetBackgroundColor(FALSE, RGB(
 				app->GetProfileInt("HeaderViewColor", "BkColorR", GetRValue(cr)),
 				app->GetProfileInt("HeaderViewColor", "BkColorG", GetGValue(cr)),
-				app->GetProfileInt("HeaderViewColor", "BkColorB", GetBValue(cr))));
-
-	
+				app->GetProfileInt("HeaderViewColor", "BkColorB", GetBValue(cr))));	
 
 	LOGFONT lf;
 	LPBYTE pData;
@@ -104,6 +102,7 @@ void CHeaderView::OnInitialUpdate()
 	}
 	this->SetFontEx(lf);
 
+	// clickable url
 	::SendMessage(m_hWnd, EM_AUTOURLDETECT, TRUE, 0);
 	this->GetRichEditCtrl().SetEventMask(ENM_LINK);
 
@@ -115,8 +114,6 @@ void CHeaderView::OnInitialUpdate()
 		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getHeaderViewBackBmp();
 	}
 	SetBkImage(strBackgroundFilePath);
-//	CString strBackgroundFilePath = app->m_app_path + HEADERVIEW_BACKGROUND_FILENAME;
-//	SetBkImage(strBackgroundFilePath);
 }
 
 BOOL CHeaderView::PreCreateWindow(CREATESTRUCT& cs) 
@@ -140,6 +137,10 @@ void CHeaderView::SetFontEx(LOGFONT &lf)
 
 void CHeaderView::SetHeaderText(CString buf)
 {
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+// end
 	int len = 0;
 	int start, end;
 	CString buf2, tmp1, tmp2;
@@ -173,6 +174,22 @@ void CHeaderView::SetHeaderText(CString buf)
 		}
 	}
 	regfree(&reg);
+
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	// set attribute of charactor
+	this->GetRichEditCtrl().GetDefaultCharFormat(cf);
+	cf.dwMask = CFM_COLOR | CFM_PROTECTED | CFM_FACE | CFM_SIZE | CFM_CHARSET | CFM_SUBSCRIPT;
+	cf.crTextColor = RGB(
+		app->GetProfileInt("HeaderViewColor", "TxtColorR", DEF_TXT_COLOR_R),
+		app->GetProfileInt("HeaderViewColor", "TxtColorG", DEF_TXT_COLOR_G),
+		app->GetProfileInt("HeaderViewColor", "TxtColorB", DEF_TXT_COLOR_B));
+	cf.dwEffects = CFE_PROTECTED | CFE_SUBSCRIPT;
+	this->GetRichEditCtrl().SetSel(0, -1);
+	this->GetRichEditCtrl().SetSelectionCharFormat(cf);
+	this->GetRichEditCtrl().HideSelection(TRUE, FALSE);
+	this->GetRichEditCtrl().SetSel(0, 0);
+// end
 }
 
 void CHeaderView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
@@ -182,7 +199,9 @@ void CHeaderView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
 
 	ENLINK * pLink = (ENLINK*)in_pNotifyHeader;
-	if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+/*	if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
 		m_onlink = pLink->lParam;
 
 		this->GetRichEditCtrl().SetSel(pLink->chrg);
@@ -207,7 +226,99 @@ void CHeaderView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 		app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 	}else if(pLink->msg == WM_RBUTTONDOWN){
 
+	}*/
+	if(app->GetProfileInt("Customize", "HeaderViewSingleClick", 1)){
+		if(pLink->msg == WM_LBUTTONUP && m_onlink != pLink->lParam){
+			m_onlink = pLink->lParam;
+
+			this->GetRichEditCtrl().SetSel(pLink->chrg);
+			CString link = this->GetRichEditCtrl().GetSelText();
+
+			// initialization.
+			app->m_me.Initialize();
+			// setting To
+			app->m_me.SetTo(link);
+
+			// setting From
+			CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
+			CString address;
+			GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			address.ReleaseBuffer();
+			app->m_me.SetFrom(address);
+
+			// setting "cc"
+			CString cc;
+			GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			cc.ReleaseBuffer();
+			app->m_me.SetCc(cc);
+
+			// setting "bcc"
+			CString bcc;
+			GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			bcc.ReleaseBuffer();
+			app->m_me.SetBcc(bcc);
+
+			// setting "reply-to"
+			CString reply_to;
+			GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			reply_to.ReleaseBuffer();
+			app->m_me.SetReplyTo(reply_to);
+
+			// getting signature.
+			CString signature;
+			g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
+			// set main text.
+			app->m_me.AddText(signature);
+			// draftframe
+			app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
+		}
+	}else{
+		if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
+			m_onlink = pLink->lParam;
+
+			this->GetRichEditCtrl().SetSel(pLink->chrg);
+			CString link = this->GetRichEditCtrl().GetSelText();
+
+			// initialization.
+			app->m_me.Initialize();
+			// setting To
+			app->m_me.SetTo(link);
+
+			// setting From
+			CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
+			CString address;
+			GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			address.ReleaseBuffer();
+			app->m_me.SetFrom(address);
+
+			// setting "cc" field
+			CString cc;
+			GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			cc.ReleaseBuffer();
+			app->m_me.SetCc(cc);
+
+			// setting "bcc" field
+			CString bcc;
+			GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			bcc.ReleaseBuffer();
+			app->m_me.SetBcc(bcc);
+
+			// setting "reply-to" field
+			CString reply_to;
+			GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+			reply_to.ReleaseBuffer();
+			app->m_me.SetReplyTo(reply_to);
+
+			// getting signature.
+			CString signature;
+			g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
+			// set main text.
+			app->m_me.AddText(signature);
+			// draftframe
+			app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
+		}
 	}
+// end
 }
 
 void CHeaderView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
