@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002-2003 chik, s.hiranaka
+ * Copyright (C) 2002-2003 chik, hiranaka
  * For license terms, see the file COPYING in this directory.
  */
 
@@ -21,12 +21,14 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
+#define MAILEDITVIEW_BACKGROUND_FILENAME _T("\\skin\\MailEditViewBk.bmp")
+
 /////////////////////////////////////////////////////////////////////////////
 // CMailEditView
 
 IMPLEMENT_DYNCREATE(CMailEditView, CRichEditView)
 
-BEGIN_MESSAGE_MAP(CMailEditView, CRichEditView)
+BEGIN_MESSAGE_MAP(CMailEditView, CBitmapRichEditView)
 	//{{AFX_MSG_MAP(CMailEditView)
 	ON_WM_CHAR()
 	ON_WM_KEYDOWN()
@@ -60,7 +62,7 @@ CMailEditView::~CMailEditView()
 
 BOOL CMailEditView::PreCreateWindow(CREATESTRUCT& cs)
 {
-	BOOL bPreCreated = CRichEditView::PreCreateWindow(cs);
+	BOOL bPreCreated = CBitmapRichEditView::PreCreateWindow(cs);
 //	cs.style &= ~(ES_AUTOHSCROLL|WS_HSCROLL);	// [h bvgp\ɂ܂
 
 	return bPreCreated;
@@ -216,6 +218,17 @@ void CMailEditView::OnInitialUpdate()
 		WrapChanged(); // ܂ԂȂ
 	}
 	r.SetOptions(ECOOP_OR,ECO_AUTOHSCROLL);
+
+	// [GfBbgr[̔wi摜ݒ
+	CString strBackgroundFilePath;
+	if(app->m_skin.getMailEditViewBackBmp() == ""){
+		strBackgroundFilePath = app->m_app_path + MAILEDITVIEW_BACKGROUND_FILENAME;
+	}else{
+		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getMailEditViewBackBmp();
+	}
+	SetBkImage(strBackgroundFilePath);
+//	CString strBackgroundFilePath = app->m_app_path + MAILEDITVIEW_BACKGROUND_FILENAME;
+//	SetBkImage(strBackgroundFilePath);
 }
 
 void CMailEditView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags) 
@@ -275,7 +288,7 @@ void CMailEditView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 		if(df->KeyDown(nChar,this))
 			return;
 	}
-	CRichEditView::OnKeyDown(nChar, nRepCnt, nFlags);
+	CBitmapRichEditView::OnKeyDown(nChar, nRepCnt, nFlags);
 }
 
 void CMailEditView::GetText(CString &buf)
@@ -355,6 +368,7 @@ void CMailEditView::Font()
 		r.SetSel(nStartChar, nEndChar);
 
 		Invalidate(TRUE);
+		this->UpdateWindow();
 	}
 }
 
