@@ -27,6 +27,11 @@
 #include "GpgDlg.h"
 #include "MainAddressBookDlg.h"
 #include "SettingGeneralDlg.h"
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#include "Template.h"
+#include "MainAddressCheckDlg.h"
+// end
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -64,8 +69,12 @@ BEGIN_MESSAGE_MAP(CMainFrame, CFrameWnd)
 	ON_UPDATE_COMMAND_UI(ID_INFO, OnUpdateInfo)
 	ON_UPDATE_COMMAND_UI(ID_SETTING, OnUpdateSetting)
 	ON_NOTIFY(TBN_DROPDOWN, AFX_IDW_TOOLBAR, OnToolbarDropDown)
-	ON_COMMAND(ID_REPLY_QUOTATION, OnReplyQuotation)
-	ON_COMMAND(ID_REPLY_NO_QUOTATION, OnReplyNoQuotation)
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	ON_COMMAND(ID_REPLY_QUOTATION, OnReplyQuotation)
+//	ON_COMMAND(ID_REPLY_NO_QUOTATION, OnReplyNoQuotation)
+	ON_COMMAND(ID_REPLY_DEFAULT, OnReply)
+// end
 	ON_WM_TIMER()
 	ON_COMMAND(ID_SETTING_GENERAL, OnSettingGeneral)
 	ON_COMMAND(ID_SETTING_ACCOUNT, OnSettingAccount)
@@ -104,8 +113,12 @@ CMainFrame::CMainFrame() : m_hRichEdit20(NULL)
 	m_button_gpg_dec = FALSE;
 	m_button_info = FALSE;
 	m_tasktray_animation_num = 0;
-
 	m_hRichEdit20 = ::LoadLibraryA("RichEd20.dll");
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	// for dynamic drop down menu
+	this->m_bAutoMenuEnable = FALSE;
+// end
 }
 
 CMainFrame::~CMainFrame()
@@ -569,8 +582,112 @@ void CMainFrame::OnSetting()
 
 void CMainFrame::OnReply() 
 {
-	// ݒőIׂ悤ɂ
-	this->OnReplyQuotation();
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	// ݒőIׂ悤ɂ
+//	this->OnReplyQuotation();
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CTemplate tmpl;
+	CString body_tmpl;
+	CMainAddressCheckDlg ad;
+	CString signature;
+	CString tmpl_body;
+
+	// initialyze
+	app->m_me.Initialize();
+
+	if(!m_pTextV->GetCurrentCc().IsEmpty()){
+		// setting cc
+		ad.SetCc(m_pTextV->GetCurrentCc());
+					
+		// setting to, if reply-to exist, use reply-to address as to address
+		if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
+			ad.SetTo(m_pTextV->GetCurrentFrom());
+		}else{
+			ad.SetTo(m_pTextV->GetCurrentReplyTo());
+		}
+
+		if(ad.DoModal() == IDOK){
+			app->m_me.SetTo(ad.GetTo());
+			app->m_me.SetCc(ad.GetCc());
+			app->m_me.SetBcc(ad.GetBcc());
+		}else{
+			return;
+		}
+	}else{
+		// setting cc
+		app->m_me.SetCc(m_pTextV->GetCurrentCc());
+
+		// setting to
+		if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
+			app->m_me.SetTo(m_pTextV->GetCurrentFrom());
+		}else{
+			app->m_me.SetTo(m_pTextV->GetCurrentReplyTo());
+		}
+	}
+
+	// setting from
+	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
+	CString address;
+	GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	address.ReleaseBuffer();
+	app->m_me.SetFrom(address);
+
+	// setting subject
+	if(m_pTextV->GetCurrentSubject().Find("Re:") == 0 || m_pTextV->GetCurrentSubject().Find("RE:") == 0){
+		app->m_me.SetSubject(m_pTextV->GetCurrentSubject());
+	}else{
+		app->m_me.SetSubject("Re: "+m_pTextV->GetCurrentSubject());
+	}
+
+	// setting "cc" field
+	CString cc;
+	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	cc.ReleaseBuffer();
+	if(!cc.IsEmpty()){
+		app->m_me.AddCc(cc);
+	}
+
+	// setting "bcc" field
+	CString bcc;
+	GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	bcc.ReleaseBuffer();
+	if(!bcc.IsEmpty()){
+		app->m_me.AddBcc(bcc);
+	}
+
+	// setting "reply-to" field
+	CString reply_to;
+	GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	reply_to.ReleaseBuffer();
+	if(!reply_to.IsEmpty()){
+		app->m_me.SetReplyTo(reply_to);
+	}
+
+	// message-id
+	app->m_me.SetMessageID(g_gen_msgid(address));
+
+	// In-reply-to
+	app->m_me.SetInReplyTo(m_pTextV->GetCurrentMsgID());
+	// setting references
+	app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
+
+	if(g_is_there(app->m_app_path+"\\template\\default_q.rtmpl")){
+		g_file2cstring(app->m_app_path+"\\template\\default_q.rtmpl", body_tmpl);
+	}else{
+		body_tmpl = DEF_REPLY_TEMPLATE;
+	}
+
+	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
+	tmpl.SetSignature(signature);
+	tmpl.SetBody(m_pTextV->GetCurrentBody());
+
+	// setting mail body
+	app->m_me.AddText(tmpl.GetString(&(m_pTextV->m_md), body_tmpl));
+
+	// create draft frame
+	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
+// end
 }
 
 void CMainFrame::OnDraft() 
@@ -595,7 +712,11 @@ void CMainFrame::OnDraft()
 
 	// setting "bcc" field
 	CString bcc;
-	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+// end
 	bcc.ReleaseBuffer();
 	app->m_me.SetBcc(bcc);
 
@@ -661,12 +782,19 @@ BOOL CMainFrame::Char(UINT nChar)
 			return TRUE;
 		case 'a': // pȂԐM
 			if(this->m_button_reply==TRUE)
-				OnReplyNoQuotation();
-			return TRUE;
-		case 'A': // pԐM
-			if(this->m_button_reply==TRUE)
-				OnReplyQuotation();
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//				OnReplyNoQuotation();
+			OnReply();
+// end
 			return TRUE;
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//		case 'A': // pԐM
+//			if(this->m_button_reply==TRUE)
+//				OnReplyQuotation();
+//			return TRUE;
+// end
 		case 'f': // ]
 			if(this->m_button_transfer==TRUE)
 				OnTransfer();
@@ -812,6 +940,11 @@ BOOL CMainFrame::CreateToolbar()
 
 void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 {
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CPochyApp* app = (CPochyApp*)AfxGetApp();
+	CFileFind ff;
+// end
 	CWnd *wnd = &m_wndToolBar;
 	UINT id;
 
@@ -841,6 +974,46 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 	menu.LoadMenu(id);
 	CMenu* pPopup = menu.GetSubMenu(0);
 	ASSERT(pPopup);
+
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	int i;
+	BOOL b;
+	switch(pnmtb->iItem){
+	case ID_REPLY:
+		this->m_template_array.RemoveAll();
+		b = ff.FindFile(app->m_app_path+"\\template\\*.*");
+		while(b){
+			b = ff.FindNextFile();
+			if(!ff.IsDirectory() && !ff.IsDots()){
+				if(ff.GetFileName().Mid(ff.GetFileName().Find(".")+1) == "rtmpl"){
+					this->m_template_array.Add(ff.GetFileName());
+				}
+			}
+		}
+		for(i=0; i<m_template_array.GetSize(); i++){
+			pPopup->AppendMenu(MF_STRING|MF_ENABLED, ID_DYNAMIC_DROP_DOWN_MENU_START+i, m_template_array.GetAt(i));
+		}
+		break;
+	case ID_TRANSFER:
+		this->m_template_array.RemoveAll();
+		b = ff.FindFile(app->m_app_path+"\\template\\*.*");
+		while(b){
+			b = ff.FindNextFile();
+			if(!ff.IsDirectory() && !ff.IsDots()){
+				if(ff.GetFileName().Mid(ff.GetFileName().Find(".")+1) == "ftmpl"){
+					this->m_template_array.Add(ff.GetFileName());
+				}
+			}
+		}
+		for(i=0; i<m_template_array.GetSize(); i++){
+			pPopup->AppendMenu(MF_STRING|MF_ENABLED, ID_DYNAMIC_DROP_DOWN_MENU_START+i, m_template_array.GetAt(i));
+		}
+		break;
+	default:
+		break;
+	}
+// end
 	
 	CRect rc;
 	wnd->SendMessage(TB_GETRECT, pnmtb->iItem, (LPARAM)&rc);
@@ -849,6 +1022,9 @@ void CMainFrame::OnToolbarDropDown(NMTOOLBAR* pnmtb, LRESULT *plr)
 	pPopup->TrackPopupMenu( TPM_LEFTALIGN | TPM_LEFTBUTTON | TPM_VERTICAL, rc.left, rc.bottom, this, &rc);
 }
 
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+/*
 void CMainFrame::OnReplyQuotation() 
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
@@ -993,7 +1169,8 @@ void CMainFrame::OnReplyNoQuotation()
 	app->m_me.AddMultipart(data);
 
 	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
-}
+}*/
+// end
 
 void CMainFrame::OnGpg()
 {
@@ -1157,7 +1334,7 @@ void CMainFrame::OnSettingNewAccount()
 	this->m_pAcntV->CreateNewAccount(name);
 	this->m_pTreeV->ConstructTree(name);
 
-	// multipartview\ĂΉB
+	// if multipartview is on display, hide
 	this->m_pListV->Clear();
 	this->m_pHeadV->Clear();
 	this->m_pTextV->Clear();
@@ -1166,18 +1343,24 @@ void CMainFrame::OnSettingNewAccount()
 void CMainFrame::OnTransferQuotation() 
 {
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CTemplate tmpl;
+	CString body_tmpl;
+	CString signature;
+// end
 
-	// Ƃ肠
+	// initialyze
 	app->m_me.Initialize();
 
-	// from̐ݒ
+	// from
 	CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
 	CString address;
 	GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 	address.ReleaseBuffer();
 	app->m_me.SetFrom(address);
 
-	// setting "cc" field
+	// setting "cc"
 	CString cc;
 	GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
 	cc.ReleaseBuffer();
@@ -1185,7 +1368,11 @@ void CMainFrame::OnTransferQuotation()
 
 	// setting "bcc" field
 	CString bcc;
-	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	GetPrivateProfileString("def_address", "address", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+	GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+// end
 	bcc.ReleaseBuffer();
 	app->m_me.SetBcc(bcc);
 
@@ -1195,12 +1382,14 @@ void CMainFrame::OnTransferQuotation()
 	reply_to.ReleaseBuffer();
 	app->m_me.SetReplyTo(reply_to);
 
-	// message-id̐ݒ
+	// message-id
 	app->m_me.SetMessageID(g_gen_msgid(address));
 
-	// subject̐ݒ
+	// subject
 	app->m_me.SetSubject("Fw: "+m_pTextV->GetCurrentSubject());
-	// {Ɉpݒ
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+/*	// {Ɉpݒ
 	CString message;
 	message += "\r\nFowarded by ";
 	message += app->m_me.GetFrom()+"\r\n";
@@ -1223,7 +1412,22 @@ void CMainFrame::OnTransferQuotation()
 	CString signature;
 	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
 	// {ݒ
-	app->m_me.AddText(body+"\r\n"+signature);
+	app->m_me.AddText(body+"\r\n"+signature);*/
+
+	if(g_is_there(app->m_app_path+"\\template\\default.ftmpl")){
+		g_file2cstring(app->m_app_path+"\\template\\default.ftmpl", body_tmpl);
+	}else{
+		body_tmpl = DEF_FORWARD_TEMPLATE;
+	}
+
+	g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
+	tmpl.SetSignature(signature);
+	tmpl.SetBody(m_pTextV->GetCurrentBody());
+	tmpl.SetAddress(address);
+
+	// setting mail body
+	app->m_me.AddText(tmpl.GetString(&(m_pTextV->m_md), body_tmpl));
+// end
 
 	app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());	
 }
@@ -1282,6 +1486,27 @@ BOOL CMainFrame::OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct)
 				address.ReleaseBuffer();
 				app->m_me.SetFrom(address);
 
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+				// setting "cc" field
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				app->m_me.SetCc(cc);
+
+				// setting "bcc" field
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				app->m_me.SetBcc(bcc);
+
+				// setting "reply-to" field
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				app->m_me.SetReplyTo(reply_to);
+// end
+
 				// setting message-id
 				app->m_me.SetMessageID(g_gen_msgid(address));
 
@@ -1426,3 +1651,167 @@ void CMainFrame::HideHeaderView(BOOL b)
 		m_split_header_text.ShowRow();
 	}
 }
+
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+BOOL CMainFrame::OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo) 
+{
+	CPochyApp *app = (CPochyApp *)AfxGetApp();
+	CString menu_item;
+	CTemplate tmpl;
+	CString body_tmpl;
+	CMainAddressCheckDlg ad;
+
+	// pHandlerInfo == NUUL means this message id is not assigned to any hendler
+	if(pHandlerInfo == NULL && ID_DYNAMIC_DROP_DOWN_MENU_START <= nID && nID <= ID_DYNAMIC_DROP_DOWN_MENU_END){
+		if(nCode == CN_COMMAND){
+			menu_item = this->m_template_array.GetAt(nID-ID_DYNAMIC_DROP_DOWN_MENU_START);
+			if(menu_item.Mid(menu_item.Find(".")+1) == "rtmpl"){
+				
+				// initialyze
+				app->m_me.Initialize();
+
+				if(!m_pTextV->GetCurrentCc().IsEmpty()){
+					// setting cc
+					ad.SetCc(m_pTextV->GetCurrentCc());
+					
+					// setting to, if reply-to exist, use reply-to address as to address
+					if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
+						ad.SetTo(m_pTextV->GetCurrentFrom());
+					}else{
+						ad.SetTo(m_pTextV->GetCurrentReplyTo());
+					}
+
+					if(ad.DoModal() == IDOK){
+						app->m_me.SetTo(ad.GetTo());
+						app->m_me.SetCc(ad.GetCc());
+						app->m_me.SetBcc(ad.GetBcc());
+					}else{
+						return TRUE;
+					}
+				}else{
+					// setting cc
+					app->m_me.SetCc(m_pTextV->GetCurrentCc());
+
+					// setting to
+					if(m_pTextV->GetCurrentReplyTo().IsEmpty()){
+						app->m_me.SetTo(m_pTextV->GetCurrentFrom());
+					}else{
+						app->m_me.SetTo(m_pTextV->GetCurrentReplyTo());
+					}
+				}
+
+				// setting from
+				CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+
+				// setting subject
+				if(m_pTextV->GetCurrentSubject().Find("Re:") == 0 || m_pTextV->GetCurrentSubject().Find("RE:") == 0){
+					app->m_me.SetSubject(m_pTextV->GetCurrentSubject());
+				}else{
+					app->m_me.SetSubject("Re: "+m_pTextV->GetCurrentSubject());
+				}
+
+				// setting "cc" field
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				if(!cc.IsEmpty()){
+					app->m_me.AddCc(cc);
+				}
+
+				// setting "bcc" field
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				if(!bcc.IsEmpty()){
+					app->m_me.AddBcc(bcc);
+				}
+
+				// setting "reply-to" field
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				if(!reply_to.IsEmpty()){
+					app->m_me.SetReplyTo(reply_to);
+				}
+
+				// message-id
+				app->m_me.SetMessageID(g_gen_msgid(address));
+
+				// In-reply-to
+				app->m_me.SetInReplyTo(m_pTextV->GetCurrentMsgID());
+				
+				// setting references
+				app->m_me.SetReferences(m_pTextV->GetCurrentMsgID());
+
+				// preparing for signature and body
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
+				tmpl.SetSignature(signature);
+				tmpl.SetBody(m_pTextV->GetCurrentBody());
+				g_file2cstring(app->m_app_path+"\\template\\"+menu_item, body_tmpl);
+				// setting mail body
+				app->m_me.AddText(tmpl.GetString(&(m_pTextV->m_md), body_tmpl));
+
+				// create draft frame
+				app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());
+
+			}else if(menu_item.Mid(menu_item.Find(".")+1) == "ftmpl"){
+
+				// initialyze
+				app->m_me.Initialize();
+
+				// from
+				CString path = app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+				tmpl.SetAddress(address);
+
+				// setting "cc" field
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				app->m_me.SetCc(cc);
+
+				// setting "bcc" field
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				app->m_me.SetBcc(bcc);
+
+				// setting "reply-to" field
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				app->m_me.SetReplyTo(reply_to);
+
+				// message-id
+				app->m_me.SetMessageID(g_gen_msgid(address));
+
+				// subject
+				app->m_me.SetSubject("Fw: "+m_pTextV->GetCurrentSubject());
+
+				// preparing for signature and body
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+m_pAcntV->GetCurrentAccountName()+"\\signature", signature);
+				tmpl.SetSignature(signature);
+				tmpl.SetBody(m_pTextV->GetCurrentBody());
+				g_file2cstring(app->m_app_path+"\\template\\"+menu_item, body_tmpl);
+
+				// setting mail body
+				app->m_me.AddText(tmpl.GetString(&(m_pTextV->m_md), body_tmpl));
+
+				app->CreateDraftFrame(this->m_pAcntV->GetCurrentAccountName());	
+			}
+		}
+		return TRUE;
+	}
+	return CFrameWnd::OnCmdMsg(nID, nCode, pExtra, pHandlerInfo);
+}
+// end
\ No newline at end of file
