@@ -37,6 +37,10 @@ public:
 	//{{AFX_VIRTUAL(CMainFrame)
 	public:
 	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	virtual BOOL OnCmdMsg(UINT nID, int nCode, void* pExtra, AFX_CMDHANDLERINFO* pHandlerInfo);
+// end
 	protected:
 	virtual BOOL OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext);
 	virtual LRESULT WindowProc(UINT message, WPARAM wParam, LPARAM lParam);
@@ -88,6 +92,10 @@ private:
 protected:  // Rg[ o[po
 	CToolBar    m_wndToolBar;
 	CStatusBar  m_wndStatusBar;
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CStringArray m_template_array;
+// end
 
 // ꂽbZ[W }bv֐
 protected:
@@ -115,8 +123,11 @@ protected:
 	afx_msg void OnUpdateInfo(CCmdUI* pCmdUI);
 	afx_msg void OnUpdateSetting(CCmdUI* pCmdUI);
 	afx_msg void OnToolbarDropDown(NMTOOLBAR* pnmh, LRESULT* plRes);
-	afx_msg void OnReplyQuotation();
-	afx_msg void OnReplyNoQuotation();
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	afx_msg void OnReplyQuotation();
+//	afx_msg void OnReplyNoQuotation();
+// end
 	afx_msg void OnTimer(UINT nIDEvent);
 	afx_msg void OnSettingGeneral();
 	afx_msg void OnSettingAccount();
