@@ -16,6 +16,10 @@
 #include "direct.h" // for _mkdir
 #include "quoted-printable.h"
 #include "base64.h"
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#include "skin.h"
+// end
 
 #ifdef _DEBUG
 #define new DEBUG_NEW
@@ -23,6 +27,11 @@
 static char THIS_FILE[] = __FILE__;
 #endif
 
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#define MULTIPARTVIEW_BACKGROUND_FILENAME _T("\\skin\\MultiPartViewBk.bmp")
+// end
+
 /////////////////////////////////////////////////////////////////////////////
 // CMultiPartView
 
@@ -89,34 +98,33 @@ void CMultiPartView::OnInitialUpdate()
 	DWORD dwStyle;
 	HWND hWnd;
 
-	// ݂̃X^CA|[gX^C֕ύX
+	// set report style
 	hWnd = lc.GetSafeHwnd();
 	dwStyle = GetWindowLong(hWnd, GWL_STYLE);
 	SetWindowLong(hWnd, GWL_STYLE, (dwStyle &~ LVS_TYPEMASK) | LVS_REPORT);
 	lc.SetExtendedStyle(LVS_EX_FULLROWSELECT);
 
-	// F̐ݒ
 	COLORREF m_colorEdit;
-	// wiF
+	// background color
 	m_colorEdit = RGB(
 		app->GetProfileInt("TextViewColor", "BkColorR", 0),
 		app->GetProfileInt("TextViewColor", "BkColorG", 0),
 		app->GetProfileInt("TextViewColor", "BkColorB", 0));
 	lc.SetBkColor(m_colorEdit);
-	// eLXg̔wiF
+	// backgroud color of charactor
 	m_colorEdit = RGB(
 		app->GetProfileInt("TextViewColor", "BkColorR", DEF_BKG_COLOR_R),
 		app->GetProfileInt("TextViewColor", "BkColorG", DEF_BKG_COLOR_G),
 		app->GetProfileInt("TextViewColor", "BkColorB", DEF_BKG_COLOR_B));
 	lc.SetTextBkColor(m_colorEdit);
-	// ̐F
+	// color of charactor
 	m_colorEdit = RGB(
 		app->GetProfileInt("TextViewColor", "TxtColorR", DEF_TXT_COLOR_R),
 		app->GetProfileInt("TextViewColor", "TxtColorG", DEF_TXT_COLOR_G),
 		app->GetProfileInt("TextViewColor", "TxtColorB", DEF_TXT_COLOR_B));
 	lc.SetTextColor(m_colorEdit);
 
-	// Xgr[փJݒ
+	// setting column
 	lvc.mask = LVCF_FMT|LVCF_TEXT|LVCF_WIDTH|LVCF_SUBITEM;
 	lvc.fmt = LVCFMT_LEFT;
 	for(int i = 0; i < 3; i++){
@@ -131,14 +139,24 @@ void CMultiPartView::OnInitialUpdate()
 
 	// setting system icon image.
 	m_image.Create(16, 16, ILC_COLORDDB | ILC_MASK, 1, 100);
-//	lc.SetImageList(&m_image, LVSIL_SMALL);
-//	m_image.Add(NULL);
+
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	// skin.ini
+	CString strBackgroundFilePath;
+	if(app->m_skin.getMultiPartViewBackBmp() == ""){
+		strBackgroundFilePath = app->m_app_path + MULTIPARTVIEW_BACKGROUND_FILENAME;
+	}else{
+		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getMultiPartViewBackBmp();
+	}
+	SetBkImage(strBackgroundFilePath);
+// end
 }
 
 void CMultiPartView::OnItemchanged(NMHDR* pNMHDR, LRESULT* pResult) 
 {
 	NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;
-	m_index = pNMListView->iItem; // ݑIĂItemۑĂ
+	m_index = pNMListView->iItem; // save current selected item
 	CPochyApp* app = (CPochyApp*)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CTextView *tv = (CTextView*)mf->m_pTextV;
@@ -170,7 +188,7 @@ void CMultiPartView::OnChar(UINT nChar, UINT nRepCnt, UINT nFlags)
 		return;
 
 	switch(nChar){
-		case VK_RETURN: // Ytt@C̏ꍇN
+		case VK_RETURN: // may be excute attached file
 //			ExecuteFile();
 			break;
 		case 'n':
@@ -228,13 +246,13 @@ void CMultiPartView::ExecuteFile()
 	g_cstra2cstr(buf, body, g_cstra_getsize(buf));
 
 	if(m_index != -1){
-		// Ytt@C̏ꍇ
+		// in case of attached file
 		if(!tv->m_md.GetFileName(m_index).IsEmpty()){
-			if(!g_is_there(app->m_app_path+"\\tmep")) // attachedtH_Ȃꍇ͍
+			if(!g_is_there(app->m_app_path+"\\tmep"))
 				_mkdir(app->m_app_path+"\\temp");
 			file_name = tv->m_md.GetFileName(m_index);
 			FILE* file = fopen(app->m_app_path+"\\temp\\"+file_name, "wb");
-			// base64̏
+			// base64
 			if(tv->GetCurrentCTE() == BASE64){
 				body.Remove('\r');
 				body.Remove('\n');
@@ -251,7 +269,7 @@ void CMultiPartView::ExecuteFile()
 				fclose(file);
 				delete out;
 			}
-			// quoted-pritablȅ
+			// quoted-pritable
 			else if(tv->GetCurrentCTE() == QUOTED_PRINTABLE){
 				char* in2 = body.GetBuffer(0);
 				char* out2 = new char[body.GetLength()+10];
@@ -273,10 +291,10 @@ void CMultiPartView::ExecuteFile()
 				fwrite(body.GetBuffer(0), sizeof(char), body.GetLength(), file);
 				fclose(file);
 			}
-			// t@CJႤ
+			// open file
 			ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+file_name, NULL, NULL, SW_SHOW);
 		}
-		// text/html̏ꍇitext/htmlbase64 quoted-printablȅKvj
+		// text/html
 		else if(g_cstr_compare(tv->m_md.GetContentType(m_index), "Text/Html")){
 			if(BASE64 == tv->GetCurrentCTE()){
 				char* in_base64 = body.GetBuffer(0);
@@ -299,19 +317,19 @@ void CMultiPartView::ExecuteFile()
 			msg_id.Replace(".", "_");
 			file_name = msg_id + ".html";
 
-			if(!g_is_there(app->m_app_path+"\\temp")) // temptH_Ȃꍇ͍
+			if(!g_is_there(app->m_app_path+"\\temp"))
 				_mkdir(app->m_app_path+"\\temp");
 			
 			FILE* file = fopen(app->m_app_path+"\\temp\\"+file_name, "wb");
-			// sjisϊ
+			// to sjis
 			CCodeConvert cc(body);
 			body = cc.ToSjis();
 			fwrite(body.GetBuffer(0), sizeof(char), body.GetLength(), file);
 			fclose(file);
-			// t@CJႤ
+			// open file
 			ShellExecute(NULL, "open", app->m_app_path+"\\temp\\"+file_name, NULL, NULL, SW_SHOW);
 		}
-		// text/plain̏ꍇitext/plainbase64 quoted-printablȅKvj
+		// text/plain
 		else if(g_cstr_compare(tv->m_md.GetContentType(m_index), "Text/Plain")){
 			if(BASE64 == tv->GetCurrentCTE()){
 				char* in_base64 = body.GetBuffer(0);
@@ -334,23 +352,23 @@ void CMultiPartView::ExecuteFile()
 			msg_id.Replace(".", "_");
 			file_name = msg_id + ".txt";
 
-			if(!g_is_there(app->m_app_path+"\\temp")) /* temptH_Ȃꍇ͍ */
+			if(!g_is_there(app->m_app_path+"\\temp"))
 				_mkdir(app->m_app_path+"\\temp");
 			
 			FILE* file = fopen(app->m_app_path+"\\temp\\"+file_name, "wb");
-			// sjisϊ
+			// to sjis
 			CCodeConvert cc(body);
 			body = cc.ToSjis();
 			fwrite(body.GetBuffer(0), sizeof(char), body.GetLength(), file);
 			fclose(file);
-			// t@CJႤ
+			// open file
 			CString editor_path = app->GetProfileString("Editor", "Path", "notepad");
 			if(editor_path.IsEmpty())
 				editor_path = "notepad";
-			// t@Cpathsetting.iniŎw肳ꂽeditorŊJ
+			// open file with designated editor
 			ShellExecute(NULL,NULL, editor_path, "\""+app->m_app_path+"\\temp\\"+file_name+"\"", NULL, SW_SHOWNORMAL);
 		}
-		// message/rfc822̏ꍇ
+		// message/rfc822
 		else if(g_cstr_compare(tv->m_md.GetContentType(m_index), "message/rfc822")){
 			if(BASE64 == tv->GetCurrentCTE()){
 				char* in_base64 = body.GetBuffer(0);
@@ -373,20 +391,20 @@ void CMultiPartView::ExecuteFile()
 			msg_id.Replace(".", "_");
 			file_name = msg_id + ".txt";
 
-			if(!g_is_there(app->m_app_path+"\\temp")) /* temptH_Ȃꍇ͍ */
+			if(!g_is_there(app->m_app_path+"\\temp"))
 				_mkdir(app->m_app_path+"\\temp");
 
 			FILE* file = fopen(app->m_app_path+"\\temp\\"+file_name, "wb");
-			// sjisϊ
+			// to sjis
 			CCodeConvert cc(body);
 			body = cc.ToSjis();
 			fwrite(body.GetBuffer(0), sizeof(char), body.GetLength(), file);
 			fclose(file);
-			// t@CJႤ
+			// open file
 			CString editor_path = app->GetProfileString("Editor", "Path", "notepad");
 			if(editor_path.IsEmpty())
 				editor_path = "notepad";
-			// t@Cpathsetting.iniŎw肳ꂽeditorŊJ
+			// open file with designated editor
 			ShellExecute(NULL,NULL, editor_path, "\""+app->m_app_path+"\\temp\\"+file_name+"\"", NULL, SW_SHOWNORMAL);
 		}
 	}
@@ -418,7 +436,6 @@ void CMultiPartView::OnMultipartSave2file()
 	CMainFrame *mf = (CMainFrame *)app->m_pMainWnd;
 
 	CTextView *tv = (CTextView *)mf->m_pTextV;
-//	CListCtrl& lc = GetListCtrl();
 
 	file_name = tv->m_md.GetFileName(m_index);
 
@@ -433,7 +450,7 @@ void CMultiPartView::OnMultipartSave2file()
 		file = fopen(path.GetBuffer(0), "wb");
 		tv->m_md.GetBody(m_index, b_cstra);
 		g_cstra2cstr(b_cstra, b_cstr, g_cstra_getsize(b_cstra));
-		// base64ŃGR[hꂽYtt@C̏ꍇ
+		// base64
 		if(tv->GetCurrentCTE() == BASE64){
 			b_cstr.Remove('\r');
 			b_cstr.Remove('\n');
@@ -441,13 +458,13 @@ void CMultiPartView::OnMultipartSave2file()
 			len = from64tobits(pOutbuf, b_cstr.GetBuffer(0), b_cstr.GetLength());
 			fwrite(pOutbuf, sizeof(char), len, file);
 		}
-		// quoted-printablȅꍇ
+		// quoted-printable
 		else if(tv->GetCurrentCTE() == QUOTED_PRINTABLE){
 			pOutbuf = Outbuf.GetBuffer(b_cstr.GetLength()+10);
 			len = fromQPtobits(pOutbuf, b_cstr.GetBuffer(0), b_cstr.GetLength());
 			fwrite(pOutbuf, sizeof(char), len, file);
 		}
-		else{ // ̑̏ꍇi7bit 8bit bin
+		else{ // other case
 			CCodeConvert cc(b_cstr);
 			b_cstr = cc.ToSjis();
 			fwrite(b_cstr.GetBuffer(0), sizeof(char), b_cstr.GetLength(), file);
