@@ -81,6 +81,10 @@
 #define IDB_DRAG                        204
 #define IDB_SUMMARYVIEW                 207
 #define IDD_SETTING_GENERAL_SKINSELECT  208
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#define IDD_MAIN_ADDRESS_CHECK          209
+// end
 #define IDC_EDIT1                       1000
 #define IDC_EDIT2                       1001
 #define IDC_PROGRESS1                   1002
@@ -88,17 +92,29 @@
 #define IDC_BUTTON1                     1003
 #define IDC_EDIT4                       1003
 #define IDC_GPG_EXPORT                  1003
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#define IDC_MAIN_ADDRESS_CHECK_TO_BUTTON 1003
+// end
 #define IDC_LIST1                       1004
 #define IDC_EDIT5                       1004
 #define IDC_BUTTON2                     1005
 #define IDC_ADDR2_LIST1                 1005
 #define IDC_FROM                        1005
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#define IDC_MAIN_ADDRESS_CHECK_CC_BUTTON 1005
+// end
 #define IDC_EDIT6                       1006
 #define IDC_BUTTON3                     1006
 #define IDC_ADDR2_DEL2                  1006
 #define IDC_FILTER_REPLACE              1006
 #define IDC_SETTING_ADDRESS             1006
 #define IDC_MAINFRAME_ADDRESSBOOK_DEL   1006
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#define IDC_MAIN_ADDRESS_CHECK_BCC_BUTTON 1006
+// end
 #define IDC_COMBO1                      1007
 #define IDC_BUTTON4                     1007
 #define IDC_PASS                        1007
@@ -112,6 +128,10 @@
 #define IDC_SETTING_USERID              1008
 #define IDC_DRAFT_ADDRESSBOOK_DST_LIST  1008
 #define IDC_BUTTON_CC                   1008
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#define IDC_MAIN_ADDRESS_CHECK_LIST     1008
+// end
 #define IDC_BUTTON6                     1009
 #define IDC_FILTER_FIELD                1009
 #define IDC_SETTING_BOXNAME             1009
@@ -239,9 +259,13 @@
 #define ID_TEXTVIEW_BROWSER             32808
 #define ID_TEXTVIEW_EDITOR              32809
 #define ID_SAVE_TO_DRAFT                32857
-#define ID_REPLY_QUOTATION              32862
-#define ID_REPLY_NO_QUOTATION           32863
-#define ID_TRANSFER_RFC822              32864
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//#define ID_REPLY_QUOTATION              32862
+//#define ID_REPLY_NO_QUOTATION           32863
+//#define ID_TRANSFER_RFC822              32864
+#define ID_REPLY_DEFAULT                32862
+// end
 #define ID_CHANGE_BK_COLOR              32865
 #define ID_CHANGE_TXT_COLOR             32866
 #define ID_HD_TXT_COLOR                 32867
@@ -270,11 +294,19 @@
 #define ID_GPG_MAIN_KEY_MANAGEMENT      32895
 #define ID_GPG_DRAFT_KEY_MANAGEMENT     32896
 #define ID_FOLDERVIEW_CLEAR_TRASH       32897
-#define ID_TRANSFER_ATTACH              32898
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//#define ID_TRANSFER_ATTACH              32898
+// end
 #define ID_SUMMARYVIEW_DEL              32899
 #define ID_SUMMARYVIEW_REBUILD          32900
 #define ID_SUMMARYVIEW_HEADER_INFO      32901
 #define ID_SUMMARYVIEW_RAWMAIL_INFO     32902
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+#define ID_DYNAMIC_DROP_DOWN_MENU_START 40000
+#define ID_DYNAMIC_DROP_DOWN_MENU_END   41000
+// end
 #define ID_INDICATOR_TEXT               59143
 #define ID_INDICATOR_PROGRESS           59144
 #define ID_INDICATOR_FOLDER             59145
@@ -284,8 +316,13 @@
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_3D_CONTROLS                     1
-#define _APS_NEXT_RESOURCE_VALUE        208
-#define _APS_NEXT_COMMAND_VALUE         32901
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//#define _APS_NEXT_RESOURCE_VALUE        208
+//#define _APS_NEXT_COMMAND_VALUE         32901
+#define _APS_NEXT_RESOURCE_VALUE        210
+#define _APS_NEXT_COMMAND_VALUE         32902
+// end
 #define _APS_NEXT_CONTROL_VALUE         1098
 #define _APS_NEXT_SYMED_VALUE           101
 #endif
