@@ -176,12 +176,23 @@ void CSummaryView::OnInitialUpdate()
 	// T}[r[̔wi摜ݒ
 //	CString strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
 	// skin.ini
-	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	CPochyApp *pApp =(CPochyApp*)::AfxGetApp();
+// end
 	CString strBackgroundFilePath;
-	if(pApp->m_skin.getSummarryViewBackBmp() == ""){
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	if(pApp->m_skin.getSummarryViewBackBmp() == ""){
+	if(app->m_skin.getSummarryViewBackBmp() == ""){
+// end
 		strBackgroundFilePath = app->m_app_path + SUMMARYVIEW_BACKGROUND_FILENAME;
 	}else{
-		strBackgroundFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getSummarryViewBackBmp();
+	// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//		strBackgroundFilePath = pApp->m_skin.getSkinIniPath() + "\\" + pApp->m_skin.getSummarryViewBackBmp();
+		strBackgroundFilePath = app->m_skin.getSkinIniPath() + "\\" + app->m_skin.getSummarryViewBackBmp();
+// end
 	}
 	SetBkImage(strBackgroundFilePath);
 
@@ -228,9 +239,6 @@ void CSummaryView::OnGetdispinfo(NMHDR* pNMHDR, LRESULT* pResult)
 
 BOOL CSummaryView::PreCreateWindow(CREATESTRUCT& cs) 
 {
-
-	// ListViewownerdataɕύXɕ\悤ɂȂ
-	// SetItemCountExs邱ƂŁAOnGetdispinfoĂ΂
 	cs.style	|= LVS_OWNERDATA 
 				| LVS_REPORT 
 				/*| LVS_SINGLESEL*/ 
@@ -640,6 +648,11 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CMainFrame *mf = (CMainFrame*)app->m_pMainWnd;
 	CFolderView *fv = (CFolderView*)mf->m_pTreeV;
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CString box_name;
+	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
+// end
 
 	POSITION Pos = this->GetListCtrl().GetFirstSelectedItemPosition();
 	int index = (int)Pos-1;
@@ -685,7 +698,28 @@ void CSummaryView::OnDblclk(NMHDR* pNMHDR, LRESULT* pResult)
 		if(fv->GetSelectedItemKind() == FV_DRAFT){
 			CUIntArray ia;
 			this->GetSelectedMail(ia);
-			CString message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ndraft폜Ă悢łH";
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//			CString message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ndraft폜Ă悢łH";
+			CString message;
+			GetPrivateProfileString(
+				"mailbox",
+				"draft",
+				"",
+				box_name.GetBuffer(BUF_LENGTH),
+				BUF_LENGTH,
+				app->m_app_path+"\\"+current_account+"\\account.ini");
+			box_name.ReleaseBuffer();
+			if(box_name.IsEmpty()){
+				message.Format("%s\r\n\r\n%s폜Ă悢łH",
+					this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+					DEF_BOXNAME_DRAFT);
+			}else{
+				message.Format("%s\r\n\r\n%s폜Ă悢łH",
+					this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+					box_name);
+			}
+// end
 			if(IDYES == AfxMessageBox(message, MB_YESNO)){
 				this->DeleteMail(ia);
 			}
@@ -702,6 +736,10 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 	CFolderView *fv = (CFolderView *)mf->m_pTreeV;
 	CStringArray cstra;
 	CString message;
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CString box_name;
+// end
 	CUIntArray ia;
 
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
@@ -714,9 +752,45 @@ void CSummaryView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags)
 			}
 			if(fv->GetSelectedItemKind() != FV_TRASH){
 				if(ia.GetSize() == 1){
-					message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//					message = this->m_array_list[this->m_stack_num-this->m_index-1].m_str2+"\r\n\r\ntrashɈڂĂ悢łH";
+					GetPrivateProfileString(
+						"mailbox",
+						"trash",
+						"",
+						box_name.GetBuffer(BUF_LENGTH),
+						BUF_LENGTH,
+						app->m_app_path+"\\"+current_account+"\\account.ini");
+					box_name.ReleaseBuffer();
+					if(box_name.IsEmpty()){
+						message.Format("%s\r\n\r\n%sɈڂĂ悢łH",
+							this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+							DEF_BOXNAME_TRASH);
+					}else{
+						message.Format("%s\r\n\r\n%sɈڂĂ悢łH",
+							this->m_array_list[this->m_stack_num-this->m_index-1].m_str2,
+							box_name);
+					}
+// end
 				}else if(ia.GetSize() > 1){
-					message = "\r\n\r\ntrashɈڂĂ悢łH";
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//					message = "\r\n\r\ntrashɈڂĂ悢łH";
+					GetPrivateProfileString(
+						"mailbox",
+						"trash",
+						"",
+						box_name.GetBuffer(BUF_LENGTH),
+						BUF_LENGTH,
+						app->m_app_path+"\\"+current_account+"\\account.ini");
+					box_name.ReleaseBuffer();
+					if(box_name.IsEmpty()){
+						message.Format("\r\n\r\n%sɈڂĂ悢łH", DEF_BOXNAME_TRASH);
+					}else{
+						message.Format("\r\n\r\n%sɈڂĂ悢łH", box_name);
+					}
+// end
 				}
 				if(IDYES == AfxMessageBox(message, MB_YESNO)){
 					this->MoveMail(ia, app->m_app_path+"\\"+current_account+"\\trash", SMRY_COLUMN_FROM);
@@ -2268,9 +2342,18 @@ void CSummaryView::WriteIniColumnOrder()
 // ǐ folder.ini ɕۑ
 void CSummaryView::SaveUnreadCount(const CString& strPath, const int nUnread, const int /*nStack*/)
 {
-	CString strBuffer;
-	strBuffer.Format(_T("%d"), nUnread);
-	::WritePrivateProfileString(_T("list"), _T("UnreadCount"), strBuffer, strPath + _T("\\folder.ini"));
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//	CString strBuffer;
+//	strBuffer.Format(_T("%d"), nUnread);
+//	::WritePrivateProfileString(_T("list"), _T("UnreadCount"), strBuffer, strPath + _T("\\folder.ini"));
+	if (strPath != _T(""))
+	{
+		CString strBuffer;
+		strBuffer.Format(_T("%d"), nUnread);
+		::WritePrivateProfileString(_T("list"), _T("UnreadCount"), strBuffer, strPath + _T("\\folder.ini"));
+	}
+// end
 }
 
 // ǐ folder.ini 擾
