@@ -81,6 +81,7 @@ public:
 	void WriteList(); // write out m_array_list into list file
 
 public:
+	int GetUnreadCount(const CString& strPath);
 	void ReadIniColumnOrder();
 	void WriteIniColumnOrder();
 	void ReadIconImage(void);
@@ -96,6 +97,9 @@ public:
 	void SetSelectBkColor(COLORREF colColor);
 
 private:
+	void RedrawUnreadCount();
+	int CalcUnreadCount(const CString& strPath);
+	void SaveUnreadCount(const CString& strPath, const int nUnread, const int nStack);
 	LPCTSTR MakeShortString(CDC* pDC, LPCTSTR lpszLong, int nColumnLen, int nOffset);
 	void RepaintSelectedItems(void);
 	COLORREF ReadIniColor(LPCTSTR lpszKeyName, COLORREF colDefault);
