@@ -26,7 +26,11 @@ CTemplate::~CTemplate()
 
 }
 
-void CTemplate::SetCurrentBody(CString body)
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//void CTemplate::SetCurrentBody(CString body)
+void CTemplate::SetBody(CString body)
+// end
 {
 	m_body = body;
 }
@@ -40,25 +44,33 @@ void CTemplate::SetCurrentBody(CString body)
 %s	
 %t	
 %c	Cc
-%n	j[XO[v
-
+%a	̃AhX
 %r	reply-to
 %m	x-mailer
-
 %M	bZ[W{
 %Q	ptbZ[W{
-%m	bZ[W{iȂj
-%q	ptbZ[W{iȂj
+%S	signature
 %%	%
 */
 
 CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
 {
 	CString buf;
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+	CString body;
+// end
 
 	for(int i=0; i<tmpl.GetLength(); i++){
 		if(tmpl[i] == '%' && (i+1) < tmpl.GetLength()){
 			switch(tmpl[i+1]){
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+			case 'a':
+				buf += m_address;
+				i++;
+				continue;
+// end
 			case 'd':
 				if(md->m_hi.GetDate().IsEmpty()){
 					buf += "none";
@@ -116,9 +128,23 @@ CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
 				i++;
 				continue;
 			case 'M':
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+				buf += m_body;
+// end
 				i++;
 				continue;
 			case 'Q':
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+				body = m_body;
+				body.Replace("\r\n","\r\n> ");
+				buf += "> "+body+"\r\n";
+				i++;
+				continue;
+			case 'S':
+				buf += m_signature;
+// end
 				i++;
 				continue;
 			case '%':
@@ -134,3 +160,16 @@ CString CTemplate::GetString(CMimeDecode *md, CString tmpl)
 	}
 	return buf;
 }
+
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+void CTemplate::SetSignature(CString signature)
+{
+	m_signature = signature;
+}
+
+void CTemplate::SetAddress(CString address)
+{
+	m_address = address;
+}
+// end
\ No newline at end of file
