@@ -92,11 +92,6 @@ void CTextView::OnInitialUpdate()
 	CPochyApp *app = (CPochyApp *)AfxGetApp();
 	CRichEditCtrl& r = GetRichEditCtrl();
 
- /*   HWND hwnd = r.m_hWnd;
-    int x = ::SendMessage (hwnd, EM_GETLANGOPTIONS, 0, 0);
-    x &= ~(IMF_AUTOFONT);
-    ::SendMessage(hwnd, EM_SETLANGOPTIONS, 0, x);*/
-
 	LOGFONT lf;
 	LPBYTE pData;
 	UINT nSize;
@@ -310,7 +305,9 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 	CString current_account = mf->m_pAcntV->GetCurrentAccountName();
 
 	ENLINK * pLink = (ENLINK*)in_pNotifyHeader;
-	if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+/*	if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
 		// dNh߂Ɍ݂̃}EX̃NbNꂽ|CgۑĂ
 		m_onlink = pLink->lParam; // ̍
 
@@ -342,7 +339,117 @@ void CTextView::OnLink(NMHDR* in_pNotifyHeader, LRESULT* out_pResult)
 			// draftframe
 			app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
 		}else{
-			ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+			ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);*/
+	if(app->GetProfileInt("Customize", "TextViewSingleClick", 1)){
+		if(pLink->msg == WM_LBUTTONUP && m_onlink != pLink->lParam){
+			// dNh߂Ɍ݂̃}EX̃NbNꂽ|CgۑĂ
+			m_onlink = pLink->lParam; // ̍
+
+			// get charactor of clicked link
+			GetRichEditCtrl().SetSel(pLink->chrg);
+			CString link = GetRichEditCtrl().GetSelText();
+
+			if(link.Find("mailto:") == 0||link.Find("Mailto:") == 0){
+				// initialization.
+				app->m_me.Initialize();
+				// setting To
+				if(link.Find("?", 7) != -1) // mailto:hoge@hoge.com?subject=PGP%20Key&Body=Please%20send%20keyƂ
+					// subject, body is not implemented.
+					app->m_me.SetTo(link.Mid(7, link.Find("?", 7)-7));
+				else
+					app->m_me.SetTo(link.Mid(7));
+
+				// setting From
+				CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+
+				// setting "cc"
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				app->m_me.SetCc(cc);
+
+				// setting "bcc"
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				app->m_me.SetBcc(bcc);
+
+				// setting "reply-to"
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				app->m_me.SetReplyTo(reply_to);
+
+				// getting signature.
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
+				// set main text.
+				app->m_me.AddText(signature);
+				// draftframe
+				app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
+			}else{
+				ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+			}
+		}
+	}else{
+		if(pLink->msg == WM_LBUTTONDBLCLK && m_onlink != pLink->lParam){
+			// dNh߂Ɍ݂̃}EX̃NbNꂽ|CgۑĂ
+			m_onlink = pLink->lParam; // ̍
+
+			// get charactor of clicked link
+			GetRichEditCtrl().SetSel(pLink->chrg);
+			CString link = GetRichEditCtrl().GetSelText();
+
+			if(link.Find("mailto:") == 0||link.Find("Mailto:") == 0){
+				// initialization.
+				app->m_me.Initialize();
+				// setting To
+				if(link.Find("?", 7) != -1) // mailto:hoge@hoge.com?subject=PGP%20Key&Body=Please%20send%20keyƂ
+					// subject, body is not implemented.
+					app->m_me.SetTo(link.Mid(7, link.Find("?", 7)-7));
+				else
+					app->m_me.SetTo(link.Mid(7));
+
+				// setting From
+				CString path = app->m_app_path+"\\"+current_account+"\\account.ini";
+				CString address;
+				GetPrivateProfileString("mailbox", "address", "", address.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				address.ReleaseBuffer();
+				app->m_me.SetFrom(address);
+
+				// setting "cc" field
+				CString cc;
+				GetPrivateProfileString("def_address", "cc", "", cc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				cc.ReleaseBuffer();
+				app->m_me.SetCc(cc);
+
+				// setting "bcc" field
+				CString bcc;
+				GetPrivateProfileString("def_address", "bcc", "", bcc.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				bcc.ReleaseBuffer();
+				app->m_me.SetBcc(bcc);
+
+				// setting "reply-to" field
+				CString reply_to;
+				GetPrivateProfileString("def_address", "reply_to", "", reply_to.GetBuffer(BUF_LENGTH), BUF_LENGTH, path);
+				reply_to.ReleaseBuffer();
+				app->m_me.SetReplyTo(reply_to);
+
+				// getting signature.
+				CString signature;
+				g_file2cstring(app->m_app_path+"\\"+current_account+"\\signature", signature);
+				// set main text.
+				app->m_me.AddText(signature);
+				// draftframe
+				app->CreateDraftFrame(mf->m_pAcntV->GetCurrentAccountName());
+			}else{
+				ShellExecute(this->GetSafeHwnd(), _T( "open" ), link, NULL, NULL, SW_NORMAL);
+			}
+// end
 		}
 	}
 }
@@ -736,11 +843,20 @@ void CTextView::SetFontColorAndLink()
 	r.HideSelection(TRUE, FALSE);
 	r.SetSel(0, 0);
 
-	// if header view is not active, set header info color.
+	// if header view is not active, set header charactor color.
 	if(!app->GetProfileInt("Customize", "HeaderView", 1)){
-		CString mail;
-		r.GetWindowText(mail);
-		r.SetSel(0, mail.Find("\r\n\r\n")+2);
+// modified by hiranaka, added to Pochy0.1.9, 2003/11/23
+// start
+//		CString mail;
+//		r.GetWindowText(mail);
+//		r.SetSel(0, mail.Find("\r\n\r\n")+2);
+		FINDTEXTEX ft;
+		ft.chrg.cpMin = 0;
+		ft.chrg.cpMax = -1;
+		ft.lpstrText = _T("\r\r");
+		long pos = r.FindText(FR_DOWN, &ft);
+		r.SetSel(0, pos);
+// end
 		r.GetSelectionCharFormat(cf);
 		cf.dwMask = CFM_COLOR | CFM_BACKCOLOR;
 		cf.crTextColor = RGB(
