@@ -48,11 +48,11 @@
 #define DEF_BOXNAME_DRAFT "e"		// default name of draft
 #define DEF_BOXNAME_TRASH "S~"		// default name of trash
 #ifdef _IPV6_
-#define X_MAILER "Pochy 0.1.8 IPv6 ready"	// x-mailer of ipv6 ready version
-#define VERSION "Pochy 0.1.8 IPv6 ready"	// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.1.9 IPv6 ready"	// x-mailer of ipv6 ready version
+#define VERSION "Pochy 0.1.9 IPv6 ready"	// version info of ipv6 ready version
 #else
-#define X_MAILER "Pochy 0.1.8"				// x-mailer of normal version
-#define VERSION "Pochy 0.1.8"				// version info of ipv6 ready version
+#define X_MAILER "Pochy 0.1.9"				// x-mailer of normal version
+#define VERSION "Pochy 0.1.9"				// version info of ipv6 ready version
 #endif
 #define COPYRIGHT "Copyright (C) 2003 Pochy project team"
 #define CONTRIBUTORS "\
@@ -98,6 +98,22 @@ Cc: %c\r\n\
 Reply-To: %r\r\n\
 X-Mailer: %m"
 
+#define DEF_REPLY_TEMPLATE "\r\n\
+On %d\r\n\
+%f wrote:\r\n\
+\r\n\
+%Q\r\n\
+%S"
+
+#define DEF_FORWARD_TEMPLATE "\r\n\
+Fowarded by %a\r\n\
+----- Original Message -----\r\n\
+From: %f\r\n\
+To: %t\r\n\
+---\r\n\
+\r\n\
+%M"
+
 #define get_app CPochyApp* app = (CPochyApp*)AfxGetApp()
 
 /////////////////////////////////////////////////////////////////////////////
